/**
 * SDRangel
 * This is the web REST/JSON API of SDRangel SDR software. SDRangel is an Open Source Qt5/OpenGL 3.0+ (4.3+ in Windows) GUI and server Software Defined Radio and signal analyzer in software. It supports Airspy, BladeRF, HackRF, LimeSDR, PlutoSDR, RTL-SDR, SDRplay RSP1 and FunCube    ---   Limitations and specifcities:    * In SDRangel GUI the first Rx device set cannot be deleted. Conversely the server starts with no device sets and its number of device sets can be reduced to zero by as many calls as necessary to /sdrangel/deviceset with DELETE method.   * Preset import and export from/to file is a server only feature.   * Device set focus is a GUI only feature.   * The following channels are not implemented (status 501 is returned): ATV and DATV demodulators, Channel Analyzer NG, LoRa demodulator   * The device settings and report structures contains only the sub-structure corresponding to the device type. The DeviceSettings and DeviceReport structures documented here shows all of them but only one will be or should be present at a time   * The channel settings and report structures contains only the sub-structure corresponding to the channel type. The ChannelSettings and ChannelReport structures documented here shows all of them but only one will be or should be present at a time    --- 
 *
 * OpenAPI spec version: 7.0.0
 * Contact: f4exb06@gmail.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */

/*
 * SWGFreqScannerFrequency.h
 *
 * 
 */

#ifndef SWGFreqScannerFrequency_H_
#define SWGFreqScannerFrequency_H_

#include <QJsonObject>


#include <QString>

#include "SWGObject.h"
#include "export.h"

namespace SWGSDRangel {

class SWG_API SWGFreqScannerFrequency: public SWGObject {
public:
    SWGFreqScannerFrequency();
    SWGFreqScannerFrequency(QString* json);
    virtual ~SWGFreqScannerFrequency();
    void init();
    void cleanup();

    virtual QString asJson () override;
    virtual QJsonObject* asJsonObject() override;
    virtual void fromJsonObject(QJsonObject &json) override;
    virtual SWGFreqScannerFrequency* fromJson(QString &jsonString) override;

    qint64 getFrequency();
    void setFrequency(qint64 frequency);

    qint32 getEnabled();
    void setEnabled(qint32 enabled);

    QString* getNotes();
    void setNotes(QString* notes);

    QString* getChannel();
    void setChannel(QString* channel);

    QString* getChannelBandwidth();
    void setChannelBandwidth(QString* channel_bandwidth);

    QString* getThreshold();
    void setThreshold(QString* threshold);

    QString* getSquelch();
    void setSquelch(QString* squelch);


    virtual bool isSet() override;

private:
    qint64 frequency;
    bool m_frequency_isSet;

    qint32 enabled;
    bool m_enabled_isSet;

    QString* notes;
    bool m_notes_isSet;

    QString* channel;
    bool m_channel_isSet;

    QString* channel_bandwidth;
    bool m_channel_bandwidth_isSet;

    QString* threshold;
    bool m_threshold_isSet;

    QString* squelch;
    bool m_squelch_isSet;

};

}

#endif /* SWGFreqScannerFrequency_H_ */
