/**
 * SDRangel
 * This is the web REST/JSON API of SDRangel SDR software. SDRangel is an Open Source Qt5/OpenGL 3.0+ (4.3+ in Windows) GUI and server Software Defined Radio and signal analyzer in software. It supports Airspy, BladeRF, HackRF, LimeSDR, PlutoSDR, RTL-SDR, SDRplay RSP1 and FunCube    ---   Limitations and specifcities:    * In SDRangel GUI the first Rx device set cannot be deleted. Conversely the server starts with no device sets and its number of device sets can be reduced to zero by as many calls as necessary to /sdrangel/deviceset with DELETE method.   * Preset import and export from/to file is a server only feature.   * Device set focus is a GUI only feature.   * The following channels are not implemented (status 501 is returned): ATV and DATV demodulators, Channel Analyzer NG, LoRa demodulator   * The device settings and report structures contains only the sub-structure corresponding to the device type. The DeviceSettings and DeviceReport structures documented here shows all of them but only one will be or should be present at a time   * The channel settings and report structures contains only the sub-structure corresponding to the channel type. The ChannelSettings and ChannelReport structures documented here shows all of them but only one will be or should be present at a time    --- 
 *
 * OpenAPI spec version: 7.0.0
 * Contact: f4exb06@gmail.com
 *
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the class manually.
 */


#include "SWGFreqDisplaySettings.h"

#include "SWGHelpers.h"

#include <QJsonDocument>
#include <QJsonArray>
#include <QObject>
#include <QDebug>

namespace SWGSDRangel {

SWGFreqDisplaySettings::SWGFreqDisplaySettings(QString* json) {
    init();
    this->fromJson(*json);
}

SWGFreqDisplaySettings::SWGFreqDisplaySettings() {
    selected_channel = nullptr;
    m_selected_channel_isSet = false;
    font_name = nullptr;
    m_font_name_isSet = false;
    transparent_background = 0;
    m_transparent_background_isSet = false;
    display_mode = 0;
    m_display_mode_isSet = false;
    speech_enabled = 0;
    m_speech_enabled_isSet = false;
    frequency_units = 0;
    m_frequency_units_isSet = false;
    show_units = 0;
    m_show_units_isSet = false;
    freq_decimal_places = 0;
    m_freq_decimal_places_isSet = false;
    power_decimal_places = 0;
    m_power_decimal_places_isSet = false;
    textcolor = 0;
    m_textcolor_isSet = false;
    drop_shadow_enabled = 0;
    m_drop_shadow_enabled_isSet = false;
    drop_shadow_color = 0;
    m_drop_shadow_color_isSet = false;
    title = nullptr;
    m_title_isSet = false;
    rgb_color = 0;
    m_rgb_color_isSet = false;
    use_reverse_api = 0;
    m_use_reverse_api_isSet = false;
    reverse_api_address = nullptr;
    m_reverse_api_address_isSet = false;
    reverse_api_port = 0;
    m_reverse_api_port_isSet = false;
    reverse_api_feature_set_index = 0;
    m_reverse_api_feature_set_index_isSet = false;
    reverse_api_feature_index = 0;
    m_reverse_api_feature_index_isSet = false;
    rollup_state = nullptr;
    m_rollup_state_isSet = false;
}

SWGFreqDisplaySettings::~SWGFreqDisplaySettings() {
    this->cleanup();
}

void
SWGFreqDisplaySettings::init() {
    selected_channel = new QString("");
    m_selected_channel_isSet = false;
    font_name = new QString("");
    m_font_name_isSet = false;
    transparent_background = 0;
    m_transparent_background_isSet = false;
    display_mode = 0;
    m_display_mode_isSet = false;
    speech_enabled = 0;
    m_speech_enabled_isSet = false;
    frequency_units = 0;
    m_frequency_units_isSet = false;
    show_units = 0;
    m_show_units_isSet = false;
    freq_decimal_places = 0;
    m_freq_decimal_places_isSet = false;
    power_decimal_places = 0;
    m_power_decimal_places_isSet = false;
    textcolor = 0;
    m_textcolor_isSet = false;
    drop_shadow_enabled = 0;
    m_drop_shadow_enabled_isSet = false;
    drop_shadow_color = 0;
    m_drop_shadow_color_isSet = false;
    title = new QString("");
    m_title_isSet = false;
    rgb_color = 0;
    m_rgb_color_isSet = false;
    use_reverse_api = 0;
    m_use_reverse_api_isSet = false;
    reverse_api_address = new QString("");
    m_reverse_api_address_isSet = false;
    reverse_api_port = 0;
    m_reverse_api_port_isSet = false;
    reverse_api_feature_set_index = 0;
    m_reverse_api_feature_set_index_isSet = false;
    reverse_api_feature_index = 0;
    m_reverse_api_feature_index_isSet = false;
    rollup_state = new SWGRollupState();
    m_rollup_state_isSet = false;
}

void
SWGFreqDisplaySettings::cleanup() {
    if(selected_channel != nullptr) { 
        delete selected_channel;
    }
    if(font_name != nullptr) { 
        delete font_name;
    }










    if(title != nullptr) { 
        delete title;
    }


    if(reverse_api_address != nullptr) { 
        delete reverse_api_address;
    }



    if(rollup_state != nullptr) { 
        delete rollup_state;
    }
}

SWGFreqDisplaySettings*
SWGFreqDisplaySettings::fromJson(QString &json) {
    QByteArray array (json.toStdString().c_str());
    QJsonDocument doc = QJsonDocument::fromJson(array);
    QJsonObject jsonObject = doc.object();
    this->fromJsonObject(jsonObject);
    return this;
}

void
SWGFreqDisplaySettings::fromJsonObject(QJsonObject &pJson) {
    ::SWGSDRangel::setValue(&selected_channel, pJson["selectedChannel"], "QString", "QString");
    
    ::SWGSDRangel::setValue(&font_name, pJson["fontName"], "QString", "QString");
    
    ::SWGSDRangel::setValue(&transparent_background, pJson["transparentBackground"], "qint32", "");
    
    ::SWGSDRangel::setValue(&display_mode, pJson["displayMode"], "qint32", "");
    
    ::SWGSDRangel::setValue(&speech_enabled, pJson["speechEnabled"], "qint32", "");
    
    ::SWGSDRangel::setValue(&frequency_units, pJson["frequencyUnits"], "qint32", "");
    
    ::SWGSDRangel::setValue(&show_units, pJson["showUnits"], "qint32", "");
    
    ::SWGSDRangel::setValue(&freq_decimal_places, pJson["freqDecimalPlaces"], "qint32", "");
    
    ::SWGSDRangel::setValue(&power_decimal_places, pJson["powerDecimalPlaces"], "qint32", "");
    
    ::SWGSDRangel::setValue(&textcolor, pJson["textcolor"], "qint32", "");
    
    ::SWGSDRangel::setValue(&drop_shadow_enabled, pJson["dropShadowEnabled"], "qint32", "");
    
    ::SWGSDRangel::setValue(&drop_shadow_color, pJson["dropShadowColor"], "qint32", "");
    
    ::SWGSDRangel::setValue(&title, pJson["title"], "QString", "QString");
    
    ::SWGSDRangel::setValue(&rgb_color, pJson["rgbColor"], "qint32", "");
    
    ::SWGSDRangel::setValue(&use_reverse_api, pJson["useReverseAPI"], "qint32", "");
    
    ::SWGSDRangel::setValue(&reverse_api_address, pJson["reverseAPIAddress"], "QString", "QString");
    
    ::SWGSDRangel::setValue(&reverse_api_port, pJson["reverseAPIPort"], "qint32", "");
    
    ::SWGSDRangel::setValue(&reverse_api_feature_set_index, pJson["reverseAPIFeatureSetIndex"], "qint32", "");
    
    ::SWGSDRangel::setValue(&reverse_api_feature_index, pJson["reverseAPIFeatureIndex"], "qint32", "");
    
    ::SWGSDRangel::setValue(&rollup_state, pJson["rollupState"], "SWGRollupState", "SWGRollupState");
    
}

QString
SWGFreqDisplaySettings::asJson ()
{
    QJsonObject* obj = this->asJsonObject();

    QJsonDocument doc(*obj);
    QByteArray bytes = doc.toJson();
    delete obj;
    return QString(bytes);
}

QJsonObject*
SWGFreqDisplaySettings::asJsonObject() {
    QJsonObject* obj = new QJsonObject();
    if(selected_channel != nullptr && *selected_channel != QString("")){
        toJsonValue(QString("selectedChannel"), selected_channel, obj, QString("QString"));
    }
    if(font_name != nullptr && *font_name != QString("")){
        toJsonValue(QString("fontName"), font_name, obj, QString("QString"));
    }
    if(m_transparent_background_isSet){
        obj->insert("transparentBackground", QJsonValue(transparent_background));
    }
    if(m_display_mode_isSet){
        obj->insert("displayMode", QJsonValue(display_mode));
    }
    if(m_speech_enabled_isSet){
        obj->insert("speechEnabled", QJsonValue(speech_enabled));
    }
    if(m_frequency_units_isSet){
        obj->insert("frequencyUnits", QJsonValue(frequency_units));
    }
    if(m_show_units_isSet){
        obj->insert("showUnits", QJsonValue(show_units));
    }
    if(m_freq_decimal_places_isSet){
        obj->insert("freqDecimalPlaces", QJsonValue(freq_decimal_places));
    }
    if(m_power_decimal_places_isSet){
        obj->insert("powerDecimalPlaces", QJsonValue(power_decimal_places));
    }
    if(m_textcolor_isSet){
        obj->insert("textcolor", QJsonValue(textcolor));
    }
    if(m_drop_shadow_enabled_isSet){
        obj->insert("dropShadowEnabled", QJsonValue(drop_shadow_enabled));
    }
    if(m_drop_shadow_color_isSet){
        obj->insert("dropShadowColor", QJsonValue(drop_shadow_color));
    }
    if(title != nullptr && *title != QString("")){
        toJsonValue(QString("title"), title, obj, QString("QString"));
    }
    if(m_rgb_color_isSet){
        obj->insert("rgbColor", QJsonValue(rgb_color));
    }
    if(m_use_reverse_api_isSet){
        obj->insert("useReverseAPI", QJsonValue(use_reverse_api));
    }
    if(reverse_api_address != nullptr && *reverse_api_address != QString("")){
        toJsonValue(QString("reverseAPIAddress"), reverse_api_address, obj, QString("QString"));
    }
    if(m_reverse_api_port_isSet){
        obj->insert("reverseAPIPort", QJsonValue(reverse_api_port));
    }
    if(m_reverse_api_feature_set_index_isSet){
        obj->insert("reverseAPIFeatureSetIndex", QJsonValue(reverse_api_feature_set_index));
    }
    if(m_reverse_api_feature_index_isSet){
        obj->insert("reverseAPIFeatureIndex", QJsonValue(reverse_api_feature_index));
    }
    if((rollup_state != nullptr) && (rollup_state->isSet())){
        toJsonValue(QString("rollupState"), rollup_state, obj, QString("SWGRollupState"));
    }

    return obj;
}

QString*
SWGFreqDisplaySettings::getSelectedChannel() {
    return selected_channel;
}
void
SWGFreqDisplaySettings::setSelectedChannel(QString* selected_channel) {
    this->selected_channel = selected_channel;
    this->m_selected_channel_isSet = true;
}

QString*
SWGFreqDisplaySettings::getFontName() {
    return font_name;
}
void
SWGFreqDisplaySettings::setFontName(QString* font_name) {
    this->font_name = font_name;
    this->m_font_name_isSet = true;
}

qint32
SWGFreqDisplaySettings::getTransparentBackground() {
    return transparent_background;
}
void
SWGFreqDisplaySettings::setTransparentBackground(qint32 transparent_background) {
    this->transparent_background = transparent_background;
    this->m_transparent_background_isSet = true;
}

qint32
SWGFreqDisplaySettings::getDisplayMode() {
    return display_mode;
}
void
SWGFreqDisplaySettings::setDisplayMode(qint32 display_mode) {
    this->display_mode = display_mode;
    this->m_display_mode_isSet = true;
}

qint32
SWGFreqDisplaySettings::getSpeechEnabled() {
    return speech_enabled;
}
void
SWGFreqDisplaySettings::setSpeechEnabled(qint32 speech_enabled) {
    this->speech_enabled = speech_enabled;
    this->m_speech_enabled_isSet = true;
}

qint32
SWGFreqDisplaySettings::getFrequencyUnits() {
    return frequency_units;
}
void
SWGFreqDisplaySettings::setFrequencyUnits(qint32 frequency_units) {
    this->frequency_units = frequency_units;
    this->m_frequency_units_isSet = true;
}

qint32
SWGFreqDisplaySettings::getShowUnits() {
    return show_units;
}
void
SWGFreqDisplaySettings::setShowUnits(qint32 show_units) {
    this->show_units = show_units;
    this->m_show_units_isSet = true;
}

qint32
SWGFreqDisplaySettings::getFreqDecimalPlaces() {
    return freq_decimal_places;
}
void
SWGFreqDisplaySettings::setFreqDecimalPlaces(qint32 freq_decimal_places) {
    this->freq_decimal_places = freq_decimal_places;
    this->m_freq_decimal_places_isSet = true;
}

qint32
SWGFreqDisplaySettings::getPowerDecimalPlaces() {
    return power_decimal_places;
}
void
SWGFreqDisplaySettings::setPowerDecimalPlaces(qint32 power_decimal_places) {
    this->power_decimal_places = power_decimal_places;
    this->m_power_decimal_places_isSet = true;
}

qint32
SWGFreqDisplaySettings::getTextcolor() {
    return textcolor;
}
void
SWGFreqDisplaySettings::setTextcolor(qint32 textcolor) {
    this->textcolor = textcolor;
    this->m_textcolor_isSet = true;
}

qint32
SWGFreqDisplaySettings::getDropShadowEnabled() {
    return drop_shadow_enabled;
}
void
SWGFreqDisplaySettings::setDropShadowEnabled(qint32 drop_shadow_enabled) {
    this->drop_shadow_enabled = drop_shadow_enabled;
    this->m_drop_shadow_enabled_isSet = true;
}

qint32
SWGFreqDisplaySettings::getDropShadowColor() {
    return drop_shadow_color;
}
void
SWGFreqDisplaySettings::setDropShadowColor(qint32 drop_shadow_color) {
    this->drop_shadow_color = drop_shadow_color;
    this->m_drop_shadow_color_isSet = true;
}

QString*
SWGFreqDisplaySettings::getTitle() {
    return title;
}
void
SWGFreqDisplaySettings::setTitle(QString* title) {
    this->title = title;
    this->m_title_isSet = true;
}

qint32
SWGFreqDisplaySettings::getRgbColor() {
    return rgb_color;
}
void
SWGFreqDisplaySettings::setRgbColor(qint32 rgb_color) {
    this->rgb_color = rgb_color;
    this->m_rgb_color_isSet = true;
}

qint32
SWGFreqDisplaySettings::getUseReverseApi() {
    return use_reverse_api;
}
void
SWGFreqDisplaySettings::setUseReverseApi(qint32 use_reverse_api) {
    this->use_reverse_api = use_reverse_api;
    this->m_use_reverse_api_isSet = true;
}

QString*
SWGFreqDisplaySettings::getReverseApiAddress() {
    return reverse_api_address;
}
void
SWGFreqDisplaySettings::setReverseApiAddress(QString* reverse_api_address) {
    this->reverse_api_address = reverse_api_address;
    this->m_reverse_api_address_isSet = true;
}

qint32
SWGFreqDisplaySettings::getReverseApiPort() {
    return reverse_api_port;
}
void
SWGFreqDisplaySettings::setReverseApiPort(qint32 reverse_api_port) {
    this->reverse_api_port = reverse_api_port;
    this->m_reverse_api_port_isSet = true;
}

qint32
SWGFreqDisplaySettings::getReverseApiFeatureSetIndex() {
    return reverse_api_feature_set_index;
}
void
SWGFreqDisplaySettings::setReverseApiFeatureSetIndex(qint32 reverse_api_feature_set_index) {
    this->reverse_api_feature_set_index = reverse_api_feature_set_index;
    this->m_reverse_api_feature_set_index_isSet = true;
}

qint32
SWGFreqDisplaySettings::getReverseApiFeatureIndex() {
    return reverse_api_feature_index;
}
void
SWGFreqDisplaySettings::setReverseApiFeatureIndex(qint32 reverse_api_feature_index) {
    this->reverse_api_feature_index = reverse_api_feature_index;
    this->m_reverse_api_feature_index_isSet = true;
}

SWGRollupState*
SWGFreqDisplaySettings::getRollupState() {
    return rollup_state;
}
void
SWGFreqDisplaySettings::setRollupState(SWGRollupState* rollup_state) {
    this->rollup_state = rollup_state;
    this->m_rollup_state_isSet = true;
}


bool
SWGFreqDisplaySettings::isSet(){
    bool isObjectUpdated = false;
    do{
        if(selected_channel && *selected_channel != QString("")){
            isObjectUpdated = true; break;
        }
        if(font_name && *font_name != QString("")){
            isObjectUpdated = true; break;
        }
        if(m_transparent_background_isSet){
            isObjectUpdated = true; break;
        }
        if(m_display_mode_isSet){
            isObjectUpdated = true; break;
        }
        if(m_speech_enabled_isSet){
            isObjectUpdated = true; break;
        }
        if(m_frequency_units_isSet){
            isObjectUpdated = true; break;
        }
        if(m_show_units_isSet){
            isObjectUpdated = true; break;
        }
        if(m_freq_decimal_places_isSet){
            isObjectUpdated = true; break;
        }
        if(m_power_decimal_places_isSet){
            isObjectUpdated = true; break;
        }
        if(m_textcolor_isSet){
            isObjectUpdated = true; break;
        }
        if(m_drop_shadow_enabled_isSet){
            isObjectUpdated = true; break;
        }
        if(m_drop_shadow_color_isSet){
            isObjectUpdated = true; break;
        }
        if(title && *title != QString("")){
            isObjectUpdated = true; break;
        }
        if(m_rgb_color_isSet){
            isObjectUpdated = true; break;
        }
        if(m_use_reverse_api_isSet){
            isObjectUpdated = true; break;
        }
        if(reverse_api_address && *reverse_api_address != QString("")){
            isObjectUpdated = true; break;
        }
        if(m_reverse_api_port_isSet){
            isObjectUpdated = true; break;
        }
        if(m_reverse_api_feature_set_index_isSet){
            isObjectUpdated = true; break;
        }
        if(m_reverse_api_feature_index_isSet){
            isObjectUpdated = true; break;
        }
        if(rollup_state && rollup_state->isSet()){
            isObjectUpdated = true; break;
        }
    }while(false);
    return isObjectUpdated;
}
}

